aboutsummaryrefslogtreecommitdiffstats
path: root/tests/test_apis.py
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test_apis.py')
-rw-r--r--tests/test_apis.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/tests/test_apis.py b/tests/test_apis.py
index 769ac83..4ed2990 100644
--- a/tests/test_apis.py
+++ b/tests/test_apis.py
@@ -371,24 +371,24 @@ class TestErrors(unittest.TestCase):
)
def testMdxExtention(self):
""" Test that appending mdx_ raises a PendingDeprecationWarning. """
_create_fake_extension(name='fake', use_old_style=True)
self.assertRaises(
- PendingDeprecationWarning,
+ DeprecationWarning,
markdown.Markdown, extensions=['fake']
)
def testShortNameExtention(self):
""" Test that using a short name raises a PendingDeprecationWarning. """
self.assertRaises(
- PendingDeprecationWarning,
+ DeprecationWarning,
markdown.Markdown, extensions=['footnotes']
)
def testStringConfigExtention(self):
""" Test that passing configs to an Extension in the name raises a PendingDeprecationWarning. """
self.assertRaises(
- PendingDeprecationWarning,
+ DeprecationWarning,
markdown.Markdown, extensions=['markdown.extension.footnotes(PLACE_MARKER=FOO)']
)
@@ -371,24 +371,24 @@ class TestErrors(unittest.TestCase):
)
def testMdxExtention(self):
- """ Test that appending mdx_ raises a PendingDeprecationWarning. """
+ """ Test that prepending mdx_ raises a DeprecationWarning. """
_create_fake_extension(name='fake', use_old_style=True)
self.assertRaises(
@@ -371,24 +371,24 @@ class TestErrors(unittest.TestCase):
)
def testShortNameExtention(self):
- """ Test that using a short name raises a PendingDeprecationWarning. """
+ """ Test that using a short name raises a DeprecationWarning. """
self.assertRaises(
@@ -371,24 +371,24 @@ class TestErrors(unittest.TestCase):
)
def testStringConfigExtention(self):
- """ Test that passing configs to an Extension in the name raises a PendingDeprecationWarning. """
+ """ Test that passing configs to an Extension in the name raises a DeprecationWarning. """
self.assertRaises(